/*      MCcoordstore - simple web based store for Minecraft points of interest
      Copyright (C) 2021  Daniel Philip Weatherill

      This program is free software: you can redistribute it and/or modify it
 under the terms of the GNU Affero General Public License as published by the
 Free Software Foundation, either version 3 of the License, or (at your option)
 any later version.

      This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 details.

      You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


.navbar ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
    overflow: hidden;
}

.navbar li {
    float: left;
    display: inline;
    border-right: 1px solid #bbb;
}

.navbar a {
    display: block;
    padding: 8px;
    background-color: #dddddd;
}

.poi_list th, .poi_list td, table.poi_list {
    border: 1px solid black;

}

.coordnum {
    width: 10ch;
}
