{#      MCcoordstore - simple web based store for Minecraft points of interest
#      Copyright (C) 2021  Daniel Philip Weatherill

#      This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your option)
# any later version.

#      This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.

#      You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#}


{% extends "base.htm" %}

{% block content %}

<h2>Login</h2>

<form method="post" action="/login">
  {{ form.csrf_token }}
  <p> {{ form.username.label }} {{ form.username }} </p>
  <p> {{ form.password.label }} {{ form.password }} </p>
  <p> {{ form.remember.label }} {{ form.remember }} </p>
  <input type="submit">
</form>

{% endblock %}
